@@ -1,3 +1,26 @@
+
+sprintf <- function(fmt, ...) {
+
+  dots <- eval(substitute(alist(...)))
+  if (length(dots) == 0)
+    return(fmt)
+
+  base::sprintf(fmt, ...)
+
+}
+
+stopf <- function(fmt = "", ..., call. = FALSE) {
+  stop(sprintf(fmt, ...), call. = call.)
+}
+
+warningf <- function(fmt = "", ..., call. = FALSE, immediate. = FALSE) {
+  warning(sprintf(fmt, ...), call. = call., immediate. = immediate.)
+}
+
+messagef <- function(fmt = "", ..., appendLF = TRUE) {
+  message(sprintf(fmt, ...), appendLF = appendLF)
+}
+
 silent <- function(expr) {
   suppressWarnings(suppressMessages(
     capture.output(result <- eval(expr, envir = parent.frame()))
@@ -46,7 +69,7 @@ list_files <- function(path = ".", pattern = NULL, all.files = FALSE,
 }
 
 # wrapper around read.dcf to workaround LC_CTYPE bug
-# (see: http://r.789695.n4.nabble.com/Bug-in-read-dcf-all-TRUE-td4690578.html)
+# (see: # https://stat.ethz.ch/pipermail/r-devel/2014-May/069046.html)
 readDcf <- function(...) {
   loc <- Sys.getlocale('LC_CTYPE')
   on.exit(Sys.setlocale('LC_CTYPE', loc))
@@ -205,6 +228,16 @@ endswith <- function(str1, str2) {
   })
 }
 
+stopIfNoLockfile <- function(project) {
+  path <- lockFilePath(project)
+  if (!file.exists(path)) {
+    stop("This project does not have a lockfile. (Have you called 'packrat::snapshot()' yet?)",
+         call. = FALSE)
+  }
+
+  invisible(TRUE)
+}
+
 stopIfNotPackified <- function(project) {
 
   if (!checkPackified(project, quiet = TRUE)) {
@@ -474,12 +507,6 @@ loadedNamespacePaths <- function() {
   result
 }
 
-# Work around namespace:stats potentially not being loaded
-setNames <- function(object = nm, nm) {
-  names(object) <- nm
-  object
-}
-
 # Drop null values in a list
 dropNull <- function(x) {
   Filter(Negate(is.null), x)
@@ -497,8 +524,15 @@ write_dcf <- function(x, file = "", append = FALSE, indent = 4,
 }
 
 symlink <- function(from, to) {
-  if (is.windows()) Sys.junction(from, to)
-  else file.symlink(from, to)
+
+  # attempt to generating the symlink
+  if (is.windows())
+    Sys.junction(from, to)
+  else
+    file.symlink(from, to)
+
+  # check to see if the file was properly generated
+  file.exists(to)
 }
 
 with_dir <- function(dir, expr) {
@@ -679,3 +713,21 @@ quietly <- function(expr) {
 onError <- function(default, expr) {
   tryCatch(expr, error = function(e) default)
 }
+
+# logger
+logTimestamper <- function() {
+  paste("[", as.character(Sys.time()), " packrat]", sep = "")
+}
+
+timestampedLog <- function(...) {
+  cat(paste(logTimestamper(), ..., "\n"))
+}
+
+# Returns a logging function when enabled, a noop function otherwise.
+verboseLogger <- function(verbose) {
+  if (verbose) {
+    timestampedLog
+  } else {
+    function(...) {}
+  }
+}
